@@ -233,6 +233,7 @@ sync_from_gda ()
 	gchar *spath;
 	gchar *epath;
 	gchar *type;
+	gchar *str;
 	
 	sections = gda_config_list_sections (GDA_CONFIG_BASE);
 	for (s = sections; s; s = s->next){
@@ -243,10 +244,11 @@ sync_from_gda ()
 			epath = g_strdup_printf ("%s/%s", spath, (char *) e->data);
 			type = gda_config_get_type (epath);
 			g_assert (type);
-			if (!strcmp (type, "string"))
-				gnome_db_config_set_string (epath,
-						gda_config_get_string (epath));
-			else if (!strcmp (type, "bool"))
+			if (!strcmp (type, "string")) {
+				str = gda_config_get_string (epath);
+				gnome_db_config_set_string (epath, str);
+				g_free (str);
+			} else if (!strcmp (type, "bool"))
 				gnome_db_config_set_boolean (epath,
 						gda_config_get_boolean (epath));
 			else if (!strcmp (type, "float"))
@@ -438,8 +440,20 @@ gnome_db_config_set_boolean (const gchar * path, gboolean new_value)
 void
 gnome_db_config_remove_section (const gchar * path)
 {
+	GSList *slist, *iter;
+	gchar *key;
 	g_return_if_fail (path != NULL);
-	gconf_client_remove_dir (get_conf_client (), path, NULL);
+	
+	slist = gconf_client_all_entries (get_conf_client (), path, NULL);
+	for (iter = slist; iter != NULL; iter = iter->next) {
+		GConfEntry *entry = iter->data;
+		
+		key = gconf_entry_get_key (entry);
+		gconf_client_unset (get_conf_client (), key, NULL);
+		gconf_entry_free (entry);
+	}
+	g_slist_free (slist);
+		
 }
 
 /**
@@ -516,14 +530,12 @@ gnome_db_config_list_sections (const gchar * path)
 		GSList *node;
 
 		for (node = slist; node != NULL; node = g_slist_next (node)) {
-			gchar *section_name =
-				strrchr ((const char *) node->data, '/');
+			gchar *section_name = strrchr ((const char *) node->data, '/');
 			if (section_name) {
-				ret = g_list_append (ret,
-						     g_strdup (section_name +
-							       1));
+				ret = g_list_append (ret, g_strdup (section_name + 1));
 			}
 		}
+		g_slist_foreach (slist, (GFunc) g_free, NULL);
 		g_slist_free (slist);
 	}
 	return ret;
