@@ -35,6 +35,7 @@ struct _GnomeDbDsnConfigPrivate {
 	GtkWidget *wstring;
 	GtkWidget *wdesc;
 	GtkWidget *wuser;
+	GtkWidget *wpassword;
 };
 
 static void gnome_db_dsn_config_class_init (GnomeDbDsnConfigClass *klass);
@@ -107,6 +108,13 @@ gnome_db_dsn_config_init (GnomeDbDsnConfig *config, GnomeDbDsnConfigClass *klass
 	config->priv->wuser = gnome_db_new_entry_widget (0, TRUE);
 	gtk_table_attach (GTK_TABLE (table), config->priv->wuser, 1, 2, 4, 5,
 			  GTK_FILL, GTK_FILL, 2, 2);
+
+	label = gnome_db_new_label_widget (_("Password"));
+	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 5, 6, GTK_FILL, GTK_FILL, 2, 2);
+	config->priv->wpassword = gnome_db_new_entry_widget (0, TRUE);
+	gtk_entry_set_visibility (GTK_ENTRY (config->priv->wpassword), FALSE);
+	gtk_table_attach (GTK_TABLE (table), config->priv->wpassword, 1, 2, 5, 6,
+			  GTK_FILL, GTK_FILL, 2, 2);
 }
 
 static void
@@ -178,6 +186,7 @@ gnome_db_dsn_config_get_info (GnomeDbDsnConfig *config)
 	dsn_info->description = g_strdup (
 		gtk_entry_get_text (GTK_ENTRY (config->priv->wdesc)));
 	dsn_info->username = g_strdup (gtk_entry_get_text (GTK_ENTRY (config->priv->wuser)));
+	dsn_info->password = g_strdup (gtk_entry_get_text (GTK_ENTRY (config->priv->wpassword)));
 
 	return dsn_info;
 }
@@ -197,4 +206,5 @@ gnome_db_dsn_config_set_info (GnomeDbDsnConfig *config, const GdaDataSourceInfo
 	gtk_entry_set_text (GTK_ENTRY (config->priv->wstring), dsn_info->cnc_string);
 	gtk_entry_set_text (GTK_ENTRY (config->priv->wdesc), dsn_info->description);
 	gtk_entry_set_text (GTK_ENTRY (config->priv->wuser), dsn_info->username);
+	gtk_entry_set_text (GTK_ENTRY (config->priv->wpassword), dsn_info->password);
 }
