@@ -201,6 +201,21 @@ gnome_db_error_dialog_new (gchar *title)
 	return GTK_WIDGET (dialog);
 }
 
+static void
+change_sensitiveness (GnomeDbErrorDialog *dialog, GnomeDbError *error_widget, gint max)
+{
+	gint pos;
+
+	pos = gnome_db_error_get_position (error_widget);
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+					   GTK_RESPONSE_YES,
+					   pos > 0);
+
+	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog),
+					   GTK_RESPONSE_NO,
+					   pos < max - 1);
+}
+
 /**
  * gnome_db_error_dialog_show_errors
  * @dialog: the GnomeDbErrorDialog widget
@@ -214,22 +229,30 @@ gnome_db_error_dialog_show_errors (GnomeDbErrorDialog *dialog,
                                    GList *error_list)
 {
 	gint ret;
+	GnomeDbError *error_widget;
+	gint max;
 
 	g_return_if_fail (GNOME_DB_IS_ERROR_DIALOG (dialog));
 
-	gnome_db_error_show (GNOME_DB_ERROR (dialog->priv->error_widget), error_list);
+	max = g_list_length (error_list);
+	error_widget = GNOME_DB_ERROR (dialog->priv->error_widget);
 
-	ret = gtk_dialog_run (GTK_DIALOG (dialog));
-	switch (ret) {
-	case GTK_RESPONSE_YES :
-		gnome_db_error_prev (GNOME_DB_ERROR (dialog->priv->error_widget));
-		break;
-	case GTK_RESPONSE_NO :
-		gnome_db_error_next (GNOME_DB_ERROR (dialog->priv->error_widget));
-		break;
-	case GTK_RESPONSE_CLOSE :
-		gtk_widget_destroy (GTK_WIDGET (dialog));
+	gnome_db_error_show (GNOME_DB_ERROR (error_widget), error_list);
+	change_sensitiveness (dialog, error_widget, max);
+
+	while ((ret = gtk_dialog_run (GTK_DIALOG (dialog))) != GTK_RESPONSE_CLOSE){
+		switch (ret) {
+		case GTK_RESPONSE_YES :
+			gnome_db_error_prev (GNOME_DB_ERROR (dialog->priv->error_widget));
+			change_sensitiveness (dialog, error_widget, max);
+			break;
+		case GTK_RESPONSE_NO :
+			gnome_db_error_next (GNOME_DB_ERROR (dialog->priv->error_widget));
+			change_sensitiveness (dialog, error_widget, max);
+			break;
+		}
 	}
+	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 /**
