@@ -30,6 +30,7 @@
 #include <gtk/gtktreeview.h>
 #include <gobject/gmarshal.h>
 #include <libgnomedb/gnome-db-form.h>
+#include <libgnomedb/gnome-db-gray-bar.h>
 #include <libgnomedb/gnome-db-grid.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-model.h>
@@ -46,10 +47,13 @@ struct _GnomeDbGridPrivate {
 	GdaDataModel *model;
 
 	/* widgets */
+	GtkWidget *title;
 	GtkWidget *scroll;
 	GtkWidget *tree_view;
 	GtkWidget *popup_menu;
 
+	gchar *title_string;
+	gboolean show_title;
 	GtkSelectionMode selection_mode;
 };
 
@@ -84,6 +88,7 @@ static GObjectClass *parent_class = NULL;
  * Callbacks
  */
 
+#if 0
 static void
 menu_describe_cb (GtkWidget *widget, gpointer user_data)
 {
@@ -110,6 +115,16 @@ menu_describe_cb (GtkWidget *widget, gpointer user_data)
 	gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 }
+#endif
+
+static void
+menu_hide_columns_cb (GtkWidget *widget, gpointer user_data)
+{
+	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+	gnome_db_grid_hide_column_titles (grid);
+}
 
 static void
 menu_save_as_cb (GtkWidget *widget, gpointer user_data)
@@ -193,6 +208,15 @@ menu_select_all_cb (GtkWidget *widget, gpointer user_data)
 	gnome_db_grid_select_all (grid);
 }
 
+static void
+menu_show_columns_cb (GtkWidget *widget, gpointer user_data)
+{
+	GnomeDbGrid *grid = (GnomeDbGrid *) user_data;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+	gnome_db_grid_show_column_titles (grid);
+}
+
 static void
 menu_unselect_all_cb (GtkWidget *widget, gpointer user_data)
 {
@@ -292,14 +316,22 @@ static GnomeUIInfo grid_popup_menu[] = {
 	{ GNOME_APP_UI_ITEM, N_("Unselect All"), N_("Unselect all selected items in list"),
 	  menu_unselect_all_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
 	  NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("Show columns"), N_("Display column headers"),
+	  menu_show_columns_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+	  NULL, 0, 0, NULL },
+	{ GNOME_APP_UI_ITEM, N_("Hide columns"), N_("Hide column headers"),
+	  menu_hide_columns_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+	  NULL, 0, 0, NULL },
 	GNOMEUIINFO_SEPARATOR,
 	{ GNOME_APP_UI_ITEM, N_("Save as..."), N_("Export data to different formats"),
           menu_save_as_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
           GTK_STOCK_SAVE_AS, 0, 0, NULL },
 	GNOMEUIINFO_SEPARATOR,
+#if 0
 	{ GNOME_APP_UI_ITEM, N_("Describe..."), N_("Describe current data set"),
           menu_describe_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
           GNOME_DB_STOCK_TABLES, 0, 0, NULL },
+#endif
 	{ GNOME_APP_UI_ITEM, N_("View detail..."), N_("View current data in more detail"),
           menu_view_detail_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
           GTK_STOCK_PROPERTIES, 0, 0, NULL },
@@ -373,8 +405,13 @@ gnome_db_grid_init (GnomeDbGrid *grid, GnomeDbGridClass *klass)
 {
 	/* allocate the internal structure */
 	grid->priv = g_new0 (GnomeDbGridPrivate, 1);
+	grid->priv->show_title = FALSE;
+	grid->priv->title_string = g_strdup (_("Title"));
 
 	/* set up widgets */
+	grid->priv->title = gnome_db_gray_bar_new (grid->priv->title_string);
+	gtk_box_pack_start (GTK_BOX (grid), grid->priv->title, 0, 1, 2);
+
 	grid->priv->scroll = gnome_db_new_scrolled_window_widget ();
 	gtk_box_pack_start (GTK_BOX (grid), grid->priv->scroll, 1, 1, 0);
 
@@ -433,6 +470,11 @@ gnome_db_grid_finalize (GObject *object)
 	g_return_if_fail (GNOME_DB_IS_GRID (grid));
 
 	/* free memory */
+	if (grid->priv->title_string) {
+		g_free (grid->priv->title_string);
+		grid->priv->title_string = NULL;
+	}
+
 	g_free (grid->priv);
 	grid->priv = NULL;
 
@@ -486,6 +528,74 @@ gnome_db_grid_new_with_model (GdaDataModel *model)
 	return GTK_WIDGET (grid);
 }
 
+/**
+ * gnome_db_grid_get_title
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Get the title for the given grid.
+ *
+ * Returns: the title associated with the grid.
+ */
+const gchar *
+gnome_db_grid_get_title (GnomeDbGrid *grid)
+{
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), NULL);
+	return (const gchar *) grid->priv->title_string;
+}
+
+/**
+ * gnome_db_grid_set_title
+ * @grid: a #GnomeDbGrid widget.
+ * @title: new title.
+ *
+ * Set the title for the given grid.
+ */
+void
+gnome_db_grid_set_title (GnomeDbGrid *grid, const gchar *title)
+{
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	if (grid->priv->title_string)
+		g_free (grid->priv->title_string);
+
+	grid->priv->title_string = g_strdup (title);
+	gnome_db_gray_bar_set_text (GNOME_DB_GRAY_BAR (grid->priv->title), title);
+}
+
+/**
+ * gnome_db_grid_get_show_title
+ * @grid: a #GnomeDbGrid widget.
+ *
+ * Get whether the title is being shown for the given grid.
+ *
+ * Returns: TRUE if the title is shown, FALSE if not.
+ */
+gboolean
+gnome_db_grid_get_show_title (GnomeDbGrid *grid)
+{
+	g_return_val_if_fail (GNOME_DB_IS_GRID (grid), FALSE);
+	return grid->priv->show_title;
+}
+
+/**
+ * gnome_db_grid_set_show_title
+ * @grid: a #GnomeDbGrid widget.
+ * @show: whether to show the title or not.
+ *
+ * Set the title displating mode for the given grid.
+ */
+void
+gnome_db_grid_set_show_title (GnomeDbGrid *grid, gboolean show)
+{
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+
+	grid->priv->show_title = show;
+	if (show)
+		gtk_widget_show (grid->priv->title);
+	else
+		gtk_widget_hide (grid->priv->title);
+}
+
 /**
  * gnome_db_grid_get_model
  */
@@ -566,6 +676,31 @@ gnome_db_grid_get_selection (GnomeDbGrid *grid)
 	return list;
 }
 
+/**
+ * gnome_db_grid_foreach_selected
+ * @grid: a #GnomeDbGrid widget.
+ * @foreach_func: function to be called for each selected row.
+ * @user_data: data to pass over to @foreach_func.
+ *
+ * Call the given function for each selected row in the #GnomeDbGrid
+ * widget.
+ */
+void
+gnome_db_grid_foreach_selected (GnomeDbGrid *grid,
+				GnomeDbGridForeachFunc foreach_func,
+				gpointer user_data)
+{
+	GList *selection;
+	GList *l;
+
+	g_return_if_fail (GNOME_DB_IS_GRID (grid));
+	g_return_if_fail (foreach_func != NULL);
+
+	selection = gnome_db_grid_get_selection (grid);
+	for (l = selection; l != NULL; l = l->next)
+		foreach_func (grid, GPOINTER_TO_INT (l->data), user_data);
+}
+
 /**
  * gnome_db_grid_select_all
  */
