@@ -25,7 +25,7 @@
 #include <libgnomedb/gnome-db-util.h>
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrenderertoggle.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtktreestore.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtktreeviewcolumn.h>
 #include "libgnomedb-private.h"
@@ -209,8 +209,34 @@ double_underscores (const gchar *str)
 	return ret;
 }
 
+static void
+add_tree_model_row (GtkTreeStore *tree_model, GdaDataModel *model,
+		    GtkTreeIter *parent, gint row)
+{
+	DataModelInfo info;
+	GtkTreeIter iter;
+	const GdaValue *value;
+
+	info.row = row;
+	info.model = model;
+	gtk_tree_store_append (tree_model, &iter, parent);
+	gtk_tree_store_set (tree_model, &iter, 0, &info, -1);
+
+	/* if column 0 of this row contains a GdaValueList,
+	   then, add a child row */
+	value = gda_data_model_get_value_at (model, 0, row);
+	if (value && value->type == GDA_VALUE_TYPE_LIST) {
+	}
+}
+
 /**
- * gnome_db_model_to_gtk_tree_model
+ * gnome_db_model_to_gtk_tree_view
+ * @model: a #GdaDataModel object.
+ *
+ * Convert a #GdaDataModel into a GtkTreeView widget, filled in
+ * with the corresponding GtkTreeModel.
+ *
+ * Returns: a pointer to the newly created object.
  */
 GtkTreeView *
 gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
@@ -219,18 +245,12 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 	gint row_count;
 	gint col_count;
 	GtkTreeView *tree_view;
-	GtkListStore *tree_model = NULL;
+	GtkTreeStore *tree_model = NULL;
 
-	tree_model = gtk_list_store_new (1, DATA_MODEL_INFO_TYPE);
+	tree_model = gtk_tree_store_new (1, DATA_MODEL_INFO_TYPE);
 	row_count = gda_data_model_get_n_rows (model);
 	for (i = 0; i < row_count; i++) {
-		DataModelInfo info;
-		GtkTreeIter iter;
-
-		info.row = i;
-		info.model = model;
-		gtk_list_store_append (tree_model, &iter);
-		gtk_list_store_set (tree_model, &iter, 0, &info, -1);
+		add_tree_model_row (tree_model, model, NULL, i);
 	}
 
 	/* create the tree view widget */
@@ -280,9 +300,9 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 			g_free (title);
 
 		column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree_view), i);
+		gtk_tree_view_column_set_sort_column_id (column, i);
 		gtk_tree_view_column_set_resizable (column, TRUE);
 		gtk_tree_view_column_set_clickable (column, TRUE);
-		gtk_tree_view_column_set_reorderable (column, TRUE);
 
 		gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (tree_model),
 						 i, sort_values,
@@ -292,8 +312,6 @@ gnome_db_model_to_gtk_tree_view (GdaDataModel *model)
 			gda_field_attributes_free (attrs);
 	}
 
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (tree_model),
-					      0, GTK_SORT_ASCENDING);
 	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (tree_view), TRUE);
 
 	return tree_view;
