@@ -23,9 +23,29 @@
 #if !defined(__gnome_db_stock_h__)
 #  define __gnome_db_stock_h__
 
-#define GNOME_DB_STOCK_DATABASE "gnome-db-database"
-#define GNOME_DB_STOCK_DESIGNER "gnome-db-designer"
-#define GNOME_DB_STOCK_SQL      "gnome-db-sql"
-#define GNOME_DB_STOCK_TABLES   "gnome-db-tables"
+#include <gdk-pixbuf/gdk-pixbuf.h>
+
+G_BEGIN_DECLS
+
+#define GNOME_DB_STOCK_AGGREGATES "gnome-db-aggregates"
+#define GNOME_DB_STOCK_CONNECT    "gnome-db-connect"
+#define GNOME_DB_STOCK_DISCONNECT "gnome-db-disconnect"
+#define GNOME_DB_STOCK_DATABASE   "gnome-db-database"
+#define GNOME_DB_STOCK_DESIGNER   "gnome-db-designer"
+#define GNOME_DB_STOCK_PROCEDURES "gnome-db-procedures"
+#define GNOME_DB_STOCK_QUERY      "gnome-db-query"
+#define GNOME_DB_STOCK_SEQUENCES  "gnome-db-sequences"
+#define GNOME_DB_STOCK_SQL        "gnome-db-sql"
+#define GNOME_DB_STOCK_TABLES     "gnome-db-tables"
+#define GNOME_DB_STOCK_TYPES      "gnome-db-types"
+
+
+
+GdkPixbuf *gnome_db_stock_get_icon_pixbuf (const gchar *stock_id);
+GdkPixbuf *gnome_db_stock_get_icon_pixbuf_file (const gchar *pixmapfile);
+gchar     *gnome_db_stock_get_icon_path (const gchar *stock_id);
+
+
+G_END_DECLS
 
 #endif
